cosinnus.models package
=======================

Subpackages
-----------

.. toctree::

    cosinnus.models.serializers

Submodules
----------

cosinnus.models.group module
----------------------------

.. automodule:: cosinnus.models.group
    :members:
    :undoc-members:
    :show-inheritance:

cosinnus.models.profile module
------------------------------

.. automodule:: cosinnus.models.profile
    :members:
    :undoc-members:
    :show-inheritance:

cosinnus.models.tagged module
-----------------------------

.. automodule:: cosinnus.models.tagged
    :members:
    :undoc-members:
    :show-inheritance:

cosinnus.models.widget module
-----------------------------

.. automodule:: cosinnus.models.widget
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: cosinnus.models
    :members:
    :undoc-members:
    :show-inheritance:
